import 'dart:convert';
import 'dart:typed_data';

import 'package:pointycastle/export.dart';
import 'package:rsa_encrypt/rsa_encrypt.dart';

class CBRSAService {
  var helper = RsaKeyHelper();
  Future<AsymmetricKeyPair<PublicKey, PrivateKey>> generateKeyPair() async {
    return await helper.computeRSAKeyPair(helper.getSecureRandom());
  }

  String signData(String data, PrivateKey privateKey) {
    return helper.sign(data, privateKey as RSAPrivateKey);
  }

  bool verifySign(List<int> data, String hash, PublicKey publicKey) {
    var signer = RSASigner(SHA256Digest(), "0609608648016503040201");
    signer.init(false, PublicKeyParameter<RSAPublicKey>(publicKey));
    return signer.verifySignature(
        Uint8List.fromList(data), RSASignature(base64Decode(hash)));
  }

  String encryptData(String data, PublicKey publicKey) {
    return encrypt(data, publicKey as RSAPublicKey);
  }

  String decryptData(String data, PrivateKey privateKey) {
    return decrypt(data, privateKey as RSAPrivateKey);
  }
}
